@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -s -l -vv
+#!/usr/share/ucs-test/runner pytest-3 -s -l -vv
 # -*- coding: utf-8 -*-
 ## desc: Create container/ou
 ## tags: [udm,apptest]
@@ -8,15 +8,13 @@
 ##   - univention-config
 ##   - univention-directory-manager-tools
 
-from __future__ import print_function
-
 import ldap.dn
 import ldap.filter
 import pytest
 
-import univention.testing.utils as utils
-import univention.testing.udm as udm_test
 import univention.testing.strings as uts
+import univention.testing.udm as udm_test
+import univention.testing.utils as utils
 from univention.testing.ucs_samba import wait_for_drs_replication
 
 
@@ -695,7 +693,7 @@ class Test_StandardContainer(object):
 		for object_type in ('container/cn', 'container/ou'):
 			defalt_containers = 'cn=default containers,%s' % (udm.UNIVENTION_CONTAINER,)
 			print('testing', object_type)
-			computerPath = lo.getAttr(defalt_containers, 'univentionComputersObject')
+			computerPath = [x.decode('UTF-8') for x in lo.getAttr(defalt_containers, 'univentionComputersObject')]
 			userPath = lo.getAttr(defalt_containers, 'univentionUsersObject')
 
 			utils.verify_ldap_object(defalt_containers, {'univentionUsersObject': userPath, 'univentionComputersObject': computerPath})
