@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2019-2021 Univention GmbH
+# Copyright 2019-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -29,8 +29,6 @@
 # <https://www.gnu.org/licenses/>.
 """Grep python tracebacks in logfiles"""
 
-from __future__ import print_function
-
 import argparse
 import collections
 import contextlib
@@ -69,7 +67,7 @@ def getfile(filename, mode):
 			yield filename, name
 
 
-def main(files, ignore_exceptions={}, out=sys.stdout):
+def main(files, ignore_exceptions=[], out=sys.stdout):
 	tracebacks = {}
 	for file_ in files:
 		with getfile(file_, 'rt') as (fd, filename):
@@ -182,11 +180,20 @@ COMMON_EXCEPTIONS = (
 	E(r'^univention.admin.uexceptions.noObject: No such object$', ['^  File "/usr/lib/python3/dist-packages/univention/admin/objects.py", line .*, in get']),  # s4c
 	# during upgrade to UCS 5.0-0
 	E("^(apt.cache.FetchFailedException|apt_pkg.Error): E:The repository 'http://localhost/univention-repository.* Release' is not signed."),
-	E('ImportError: No module named client', ['univention-directory-listener/system/faillog.py', 'univention-directory-listener/system/udm_extension.py', 'univention-directory-listener/system/portal_groups.py', 'univention-directory-listener/system/app_attributes.py'], (53290, 53862)),
+	E('ImportError: No module named client', [
+		'univention-directory-listener/system/faillog.py',
+		'univention-directory-listener/system/udm_extension.py',
+		'univention-directory-listener/system/portal_groups.py',
+		'univention-directory-listener/system/app_attributes.py'
+	], (53290, 53862)),
 	E("AttributeError: 'ConfigRegistry' object has no attribute '_walk'", ['univention-directory-listener/system/nfs-shares.py'], (53291, 53862)),
 	E("AttributeError: 'module' object has no attribute 'localization'", ['univention-directory-listener/system/app_attributes.py'], 53862),
-	E("ConnectionRefusedError: \[Errno 111\] Connection refused", ['univention-self-service-invitation'], 53670),
+	E("ConnectionRefusedError: \\[Errno 111\\] Connection refused", ['univention-self-service-invitation'], 53670),
+	E("ConnectionRefusedError: \\[Errno 111\\] Connection refused", ['univention/lib/umc.py.*in send'], 53670),
 	E("univention.lib.umc.ConnectionError: .*Could not send request.*Connection refused", ['univention-self-service-invitation'], 53670),
+	E("ssl.SSLCertVerificationError.*self signed certificate in certificate chain", ['univention/lib/umc.py.*in send'], 53670),
+	E("univention.lib.umc.ConnectionError: .*Could not send request.*SSLCertVerificationError", ['univention-self-service-invitation'], 53670),
+	E("FileNotFoundError: \\[Errno 2\\] No such file or directory: '/etc/machine.secret'", ['univention/lib/umc.py.*in authenticate_with_machine_account'], 53670),
 
 	# updater test cases:
 	E('urllib.error.URLError: .*', ['updater/tools.py.*in access']),
@@ -231,7 +238,9 @@ COMMON_EXCEPTIONS = (
 	E("ucsschool.importer.exceptions.InvalidBirthday: Birthday has invalid format: '.*' error: time data '.*' does not match format '%Y-%m-%d'.", ['user_import.py.* in create_and_modify_users'], 53564),
 	E("ucsschool.importer.exceptions.UcsSchoolImportSkipImportRecord: Skipping user '.*' with firstname starting with \".\"", ['user_import.py.* in create_and_modify_users'], 53564),
 	E("ucsschool.importer.exceptions.TooManyErrors: More than 0 errors.", ['cmdline.py.* in main', 'in import_users'], 53564),
-	E(r"ucsschool.importer.exceptions.InitialisationError: Configuration value of username:max_length:default is .*, but must not be higher than UCR variable ucsschool/username/max_length \(20\).", ['in prepare_import'], 53564),
+	E(
+		r"ucsschool.importer.exceptions.InitialisationError: Configuration value of username:max_length:default is .*, "
+		r"but must not be higher than UCR variable ucsschool/username/max_length \(20\).", ['in prepare_import'], 53564),
 	E("ucsschool.importer.exceptions.InitialisationError: The 'user_deletion' configuration key is deprecated. Please set 'deletion_grace_period'.", ['in prepare_import'], 53564),
 	E("ucsschool.importer.exceptions.InitialisationError: Thou shalt not import birthdays!", ['in prepare_import'], 53564),
 	E("ucsschool.importer.exceptions.InitialisationError: Deprecated configuration key 'scheme:username:allow_rename'.", ['in prepare_import'], 53564),
@@ -254,6 +263,7 @@ COMMON_EXCEPTIONS = (
 	E("ldap.CONSTRAINT_VIOLATION: .*unique index violation on objectSid", ['in sync_from_ucs'], 43775),  # a test creates a user with the default Administrators SID, which creates a SID-Conflict
 	# Tracebacks caused by specific bugs:
 	E(r'^ldap\.NO_SUCH_OBJECT: .*', [r'quota\.py'], 52765),
+	E(r'^ldap\.INVALID_CREDENTIALS: .*', [r'quota\.py.*_is_container_change_relevant'], 54518),  # join.log
 	E(r'.*OperationalError.*FATAL:.*admindiary.*', [r'admindiary_backend_wrapper\.py', '_wrap_pool_connect'], 51671),
 	E(r"(OSError|FileNotFoundError): \[Errno 2\] .*: '/var/lib/samba/sysvol/.*/Policies/'", [r'sysvol-cleanup\.py'], 51670),
 	E("AttributeError: 'NoneType' object has no attribute 'lower'", ['_remove_subtree_in_s4'], 50282),
